package de.cnam.jemina.objects.factory;

import de.cnam.jemina.database.DatabasePersistents;
import de.cnam.jemina.objects.Artikel;
import de.cnam.jemina.objects.Buch;
import de.cnam.jemina.objects.CD;
import de.cnam.jemina.objects.Video;
import de.cnam.jemina.objects.Zeitschrift;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Factory-Klasse f&uuml;r Objekte
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public abstract class ObjectFactory {
    
    // Logging:
    private static final Logger log = LoggerFactory.getLogger(ObjectFactory.class);

    /**
     * Erstellt einen Artikel
     *
     * @param id
     * @param titel
     * @param beschreibung
     * @param typ
     * @return
     */
    public static Artikel genArtikel(int id, String titel, String beschreibung, String typ) {
        Artikel a = null;

        // Nur Dummies erstellen
        switch (typ) {
            case DatabasePersistents.ARTIKEL_BUCH:
                a = new Buch(null, null, null, null);
                break;
            case DatabasePersistents.ARTIKEL_CD:
                a = new CD(0, null, null);
                break;
            case DatabasePersistents.ARTIKEL_VIDEO:
                a = new Video(0, 0, null, null, null);
                break;
            case DatabasePersistents.ARTIKEL_ZEITSCHRIFT:
                a = new Zeitschrift(null, null, null);
                break;
            default:
                a = null;
                log.warn("Unbekannter Artikel-Typ: {}", typ);
        }
        
        if (a != null) {
            a.setId(id);
            a.setBeschreibung(beschreibung);
            a.setTitel(titel);
        }

        return a;
    }
}
