package de.cnam.jemina.ui.controlls;

import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.extern.auth.IUserDirectory;
import de.cnam.jemina.ui.controlls.impl.DisplaySearchResultsControll;
import de.cnam.jemina.ui.controlls.impl.ListMyItemsControll;
import de.cnam.jemina.ui.controlls.impl.LoanControll;
import de.cnam.jemina.ui.controlls.impl.LoginControll;
import de.cnam.jemina.ui.controlls.impl.LogoutControll;
import de.cnam.jemina.ui.controlls.impl.StartpageControll;

/**
 * Factory-Klasse um {@link IControl Controll-Klassen} zu erzeugen.
 * @author CNAM Team (Nadine, Mike, Jens)
 * @since 22.01.2013
 */
public abstract class ControllFactory {
    
    /**
     * Erstellt das Modul "{@link StartpageControll Startseite}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @return 
     */
    public static IControll createStartpageControll(IJeminaApplication app) {
        return new StartpageControll(app);
    }
    
    /**
     * Erstellt das Modul "{@link LoginControll Login}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @param ud Schnittstelle zur User-Verwaltung
     * @return 
     */
    public static IControll createLoginControll(IJeminaApplication app, IUserDirectory ud) {
        return new LoginControll(app, ud);
    }
    
    /**
     * Erstellt das Modul "{@link LogoutControll Logout}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @return 
     */
    public static IControll createLogoutControll(IJeminaApplication app) {
        return new LogoutControll(app);
    }
    
    /**
     * Erstellt das Modul "{@link DisplaySearchResultsControll Logout}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @return 
     */
    public static IControll createSearchResultsControll(IJeminaApplication app) {
        return new DisplaySearchResultsControll(app);
    }
    
    /**
     * Erstellt das Modul "{@link ListMyItemsControll Logout}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @return 
     */
    public static IControll createListMyItemsControll(IJeminaApplication app) {
        return new ListMyItemsControll(app);
    }
    
    /**
     * Erstellt das Modul "{@link LoanControll Logout}"
     * @param app Die Anwendung (wird zur Kommunikation zwischen Controll und Anwendung benoetigt)
     * @return 
     */
    public static IControll createLoanControll(IJeminaApplication app) {
        return new LoanControll(app);
    }

}
