package de.cnam.jemina.ui.controlls.listener;

import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Artikel;
import de.cnam.jemina.objects.Filiale;
import de.cnam.jemina.ui.components.DisplayArticle.IArticleControllerListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.vaadin.dialogs.ConfirmDialog;

/**
 * Listener f&uuml;r Aktionen die auf einem Artikel ausgef&uuml;hrt werden k&ouml;nnen
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class ArticleControllListener implements IArticleControllerListener {
    
    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(ArticleControllListener.class);
    
    // Logging:
    private final Logger log = LoggerFactory.getLogger(ArticleControllListener.class);
    
    private IJeminaApplication app;

    public ArticleControllListener(IJeminaApplication app) {
        super();
        this.app = app;
    }
    
    @Override
    public void deleteArticle(Artikel a) {
        // Frage den Anwender noch mal
        ConfirmDialog.show(app.getVaadinWindow(), locale.localize("loeschentitel"), locale.localize("loeschen", null, new String[]{String.valueOf(a.getId()), a.getTitel()}),
                locale.localize("yesdelete"), locale.localize("nodontdelete"), new ConfirmDialog.Listener() {
            @Override
            public void onClose(ConfirmDialog dialog) {
                if (dialog.isConfirmed()) {
                    // @todo ...
                }
            }
        });
//        app.showInfo(locale.localize("notyetimplemented"));
    }
    
    @Override
    public void saveArticle(Artikel a) {
        app.showInfo(locale.localize("notyetimplemented"));
    }
    
    @Override
    public void reserveArticle(Artikel a) {
        try {
            // @todo: Test Implementierung!!!!
            Filiale f = new Filiale(0, null, 0, null, null);
            
            final String number = app.getPersistentObj().reserve(a, f, app.getUser());
            if (number == null) {
                throw new Exception("Keine Reservierung erfolgt");
            }
            
            // Zeige Erfolgsmeldung:
            ConfirmDialog.show(app.getVaadinWindow(), locale.localize("reservetitel"), 
                    locale.localize("reserve", null, new String[]{number}), locale.localize("reserveok"), 
                    locale.localize("reserveabort"), new ConfirmDialog.Listener() {
                @Override
                public void onClose(ConfirmDialog cd) {
                    if (!cd.isConfirmed()) {
                        // Reservierung zurueckziehen
                        try {
                            app.getPersistentObj().delReserve(number);
                        } catch (Exception ex) {
                            log.error("Fehler beim loeschen der Reservierung", ex);
                        }
                    }
                }
            });
        } catch (Exception ex) {
            log.warn("Fehler bei Reservierung: {}", ex.getLocalizedMessage());
            app.showError(locale.localize("reserveerror"));
        }
    }
    
    @Override
    public void addExemplar(Artikel a) {
        // @todo: Modulname fest hinterlegt
        app.showInfo(locale.localize("notyetimplemented"));
//        app.openModul("addExemplar", a, null);
    }

}
