package de.cnam.jemina.ui.views.impl;

import com.vaadin.data.Container;
import com.vaadin.data.Property;
import com.vaadin.data.Property.ValueChangeEvent;
import com.vaadin.data.util.BeanItem;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.Table;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.VerticalSplitPanel;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Artikel;
import de.cnam.jemina.ui.components.ArticleIconColumnGenerator;
import de.cnam.jemina.ui.components.DisplayArticle;
import de.cnam.jemina.ui.components.SearchComponent;
import de.cnam.jemina.ui.controlls.impl.DisplaySearchResultsControll;
import de.cnam.jemina.ui.views.utils.ViewUtils;

/**
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class DisplaySearchResultsView extends CustomComponent {

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(DisplaySearchResultsView.class);
    
    // Controller
    private DisplaySearchResultsControll controll;
    
    // UI
    private SearchComponent sucheLeiste;
    private Table table;
    private DisplayArticle display;

    public DisplaySearchResultsView(DisplaySearchResultsControll ctrl) {
        super();
        controll = ctrl;
        setSizeFull();
        setCompositionRoot(buildContent());
    }
    
    private Component buildContent() {
        VerticalLayout layout = new VerticalLayout();
        layout.setSpacing(true);
        layout.setMargin(true);
        layout.setSizeFull();
        
        sucheLeiste = new SearchComponent();
//        sucheLeiste.setWidth(100F, UNITS_PERCENTAGE);
        layout.addComponent(sucheLeiste);
        layout.setComponentAlignment(sucheLeiste, Alignment.MIDDLE_CENTER);
        
        VerticalSplitPanel split = new VerticalSplitPanel();
        split.setSizeFull();        
        layout.addComponent(split);
        layout.setExpandRatio(split, 100F);
        
        table = new Table();
        table.setSizeFull();
        table.setSelectable(true);
        table.setMultiSelect(false);
        table.setImmediate(true);
        table.setColumnCollapsingAllowed(true);
        table.addListener(new ItemSelection());
        split.setFirstComponent(table);        
        
        display = new DisplayArticle();
        split.setSecondComponent(display);
        
        split.setSplitPosition(260, UNITS_PIXELS, true);
        
        return layout;
    }
    
    /**
     * Setzt die &Uuml;berschrift
     * @param txt Suchbegriff der gesucht wurde
     */
    public void setSearchWord(String txt) {
        sucheLeiste.setValue(txt);
    }
    
    /**
     * Setzt die Suchergebnisdaten
     * @param container 
     */
    public void setResultList(Container container) {
        table.setContainerDataSource(container);
        table.addGeneratedColumn("typ", new ArticleIconColumnGenerator());
        
        // Filiale anzeigen
        // @todo: DIES IST EIN QUICK&DIRTY HACK!!
        table.addGeneratedColumn("filiale", new Table.ColumnGenerator() {
            @Override
            public Object generateCell(Table source, Object itemId, Object columnId) {
                return "Bibliothek h-da";
            }
        });
        
        // Sortierung:
        table.setSortContainerPropertyId("titel");
        table.setSortAscending(true);
        
        // Spaltenbreite:
        table.setColumnExpandRatio("titel", 100F);
        
        // Spaltenueberschriften:
        ViewUtils.translateTableHeader(table, locale);
        
        // Anzuzeigende Spalten:
        table.setVisibleColumns(new String[] { "typ", "id", "titel", "beschreibung", "filiale" });
        
        // Spalten ausblenden:
        table.setColumnCollapsed("id", true);
        
    }
    
    /**
     * @see Suche#setSuchListener(de.cnam.jemina.ui.components.Suche.SuchListener) 
     */
    public void setSuchListener(SearchComponent.SuchListener listener) {
        sucheLeiste.setSuchListener(listener);
    }
    
    /**
     * @see DisplayArticle#setArticle(de.cnam.jemina.objects.Artikel) 
     * @param article Artikel der angezeigt werden soll
     */
    public void setArticle(Artikel article) {
        display.setArticle(article);
    }

    /**
     * Liefert die Tabelle, welche dem Anwender angezeigt wird
     * @return 
     */
    public Table getTable() {
        return table;
    }
    
    /**
     * Setzt die Berechtigungen, die der Anwender hat
     * @param canEdit <b>true</b> = Anwender kann den Artikel bearbeiten
     * @param seeId <b>true</b> = Anwender sieht die Artikel-ID
     * @param canDel <b>true</b> = Anwender kann den Artikel l&ouml;schen
     * @param canAdd <b>true</b> = Anwender kann Exemplare hinzuf&uuml;gen
     * @param canReserve <b>true</b> = Anwender kann ein Exemplar reservieren
     */
    public void setRights(boolean canEdit, boolean seeId, boolean canDel, boolean canAdd, boolean canReserve) {
        display.setCanEdit(canEdit);
        display.setSeeId(seeId);
        display.setCanDel(canDel);
        display.setCanAdd(canAdd);
        display.setCanReserve(canReserve);
    }
    
    /**
     * @see DisplayArticle#setActionListener(de.cnam.jemina.ui.components.DisplayArticle.IArticleControllerListener) 
     * @param listener 
     */
    public void setActionListener(DisplayArticle.IArticleControllerListener listener) {
        display.setActionListener(listener);
    }
    
    
    /**
     * Wenn ein Datensatz ausgewaehlt wurde ...
     */
    private class ItemSelection implements Property.ValueChangeListener {

        @Override
        public void valueChange(ValueChangeEvent event) {
            Object selectedId = table.getValue();
            if (selectedId != null) {
                BeanItem bi = (BeanItem) table.getItem(selectedId);
                setArticle( controll.loadArtikelDetails((Artikel)bi.getBean()) );
            }
        }        
    }
}
