package de.cnam.jemina.ui.views.impl;

import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.ComboBox;
import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.Label;
import com.vaadin.ui.ListSelect;
import com.vaadin.ui.TextField;
import com.vaadin.ui.VerticalLayout;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Reservierung;
import de.cnam.jemina.ui.components.SearchComponent;
import java.util.List;

/**
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class LoanView extends CustomComponent {

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(LoanView.class);

    // UI
    private VerticalLayout layout;
    private SearchComponent sucheLeiste;
    private Label infoTxt;
    
    private VerticalLayout infoLayout;
    private TextField titel;
    private TextField artikelId;
    private TextField userId; // Von dem der es ausgeliehen hat
    private ComboBox exemplarid;
    private Button ausleihen;
    
    // 
    private Reservierung reservierung;

    public LoanView() {
        super();
//        setSizeFull();
        setCompositionRoot(buildContent());
    }
    
    private Component buildContent() {
        layout = new VerticalLayout();
        layout.setSizeFull();
        layout.setMargin(true);
        
        VerticalLayout subLayout = new VerticalLayout();
        subLayout.setSpacing(true);
        layout.addComponent(subLayout);
        layout.setComponentAlignment(subLayout, Alignment.MIDDLE_CENTER);
        
        infoTxt = new Label(locale.localize("infotext"));
        sucheLeiste = new SearchComponent();
        sucheLeiste.setInputPrompt(locale.localize("enterreservenr"));
        
        infoLayout = new VerticalLayout();
        infoLayout.setSpacing(true);
        infoLayout.setSizeFull();
        infoLayout.setCaption(locale.localize("details"));
        infoLayout.setStyleName("info");
        titel = new TextField(locale.localize("artikeltitel"));
        artikelId = new TextField(locale.localize("artikelid"));
        exemplarid = new ComboBox(locale.localize("exemplarid"));
        exemplarid.setInputPrompt(locale.localize("exemplarid"));
        ausleihen = new Button(locale.localize("ausleihe"));
        userId = new TextField(locale.localize("userid"));
        
        exemplarid.setImmediate(true);
        exemplarid.setNullSelectionAllowed(false);
        exemplarid.setInvalidAllowed(false);
        
        titel.setWidth(400, UNITS_PIXELS);
        artikelId.setWidth(400, UNITS_PIXELS);
        exemplarid.setWidth(400, UNITS_PIXELS);
        userId.setWidth(400, UNITS_PIXELS);        
        
        infoLayout.setVisible(false);
        infoLayout.addComponent(artikelId);
        infoLayout.addComponent(titel);
        infoLayout.addComponent(userId);
        infoLayout.addComponent(exemplarid);
        infoLayout.addComponent(ausleihen);
        
        subLayout.addComponent(infoTxt);
        subLayout.addComponent(sucheLeiste);
        subLayout.addComponent(infoLayout);
        
        sucheLeiste.focus();
        
        return layout;
    }
    
    /**
     * Liefert die eingegebene Exemplar-ID
     * @return 
     */
    public Object getExemplarId() {
        return exemplarid.getValue();
    }
    
    /**
     * Dieser Listener wird aufgerufen, wenn der Mitarbeiter eine Exemplar-Nr. eingegeben hat
     * @param listener 
     */
    public void addAusleiheListener(Button.ClickListener listener) {
        ausleihen.addListener(listener);
    }
    
    /**
     * Zeigt Reservierungdetails an
     * @param res 
     * @param availableExemplarIds Exemplar-ID's die passend zum Artikel sind
     */
    public void showReservierung(Reservierung res, List<Integer> availableExemplarIds) {
        reservierung = res;
        
        infoLayout.setVisible(true);
        
        titel.setReadOnly(false);
        artikelId.setReadOnly(false);
        userId.setReadOnly(false);
        
        titel.setValue(res.getArtikel().getTitel());
        artikelId.setValue(res.getArtikel().getId());
        userId.setValue(res.getBesitzer().getUser_id());
        
        titel.setReadOnly(true);
        artikelId.setReadOnly(true);
        userId.setReadOnly(true);
        
        exemplarid.setContainerDataSource(new ListSelect(null, availableExemplarIds));
        exemplarid.focus();
    }

    /**
     * @see Suche#setSuchListener(de.cnam.jemina.ui.components.Suche.SuchListener) 
     */
    public void setSuchListener(SearchComponent.SuchListener listener) {
        sucheLeiste.setSuchListener(listener);
    }

    /**
     * Liefert die aktuell angezeigt Reservierung
     * @return 
     */
    public Reservierung getReservierung() {
        return reservierung;
    }
    
}
